import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:access_contacts/access_contacts.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({super.key});

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  final _accessContactsPlugin = AccessContacts();

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion = await _accessContactsPlugin.getPlatformVersion() ??
          'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
          appBar: AppBar(
              backgroundColor: Colors.transparent,
              leading: IconButton(
                icon: const Icon(Icons.arrow_back, color: Colors.white,),
                onPressed: () => Navigator.of(context).pop(),
              ),
            actions: [
              IconButton(
                  onPressed: ()=>{
                    getContacts(),
                  setState(() {})
              },
                  icon: Icon(Icons.refresh))
            ],
          ),
        floatingActionButton: FloatingActionButton.extended(
          onPressed: () => {addNewContact()},
          label: const Text('Add New Contact'),
          icon: const Icon(Icons.add),
          backgroundColor: Colors.yellow[800],
        ),
        body:
        FutureBuilder(
          builder: (context, snapshot) {
            if (ConnectionState.active != null && !snapshot.hasData) {
              return Center(
                child: Text("Loading contacts"),
              );
            }
            if (ConnectionState.done != null && snapshot.hasError) {
              return Center(
                child: Text("Error"),
              );
            }
            return ListView.builder(
              itemCount: snapshot.data?.length,
              itemBuilder: (context, index) {
                return Container(
                  decoration: BoxDecoration(
                      border: Border.all(color: Colors.grey, width: 1)),
                  margin: EdgeInsets.all(5),
                  padding: EdgeInsets.all(10),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Text(snapshot.data![index]["name"]!),
                      SizedBox(
                        height: 5,
                      ),
                      Text(snapshot.data![index]["phone"]!),
                    ],
                  ),
                );
              },
            );
          },
          future: getContacts(),
        ),
      ),
    );
  }

  Future<List<Map<String, String>>> getContacts() async {
    List<Map<String, String>> contactList =
        await _accessContactsPlugin.getAllCotntacts();
    return contactList;
  }

  Future addNewContact() async {
    var addContact = await _accessContactsPlugin.addNewContact();
  }
}
